<?php
// $Id: toolbar.comprofiler.html.php,v 1.2 2005/01/03 06:07:13 mambojoe Exp $
/**
* User Menu Button Bar HTML
* @package Mambo Open Source
* @Copyright (C) 2000 - 2003 Miro International Pty Ltd
* @ All rights reserved
* @ Mambo Open Source is Free Software
* @ Released under GNU/GPL License : http://www.gnu.org/copyleft/gpl.html
* @version $Revision: 1.2 $
**/

class TOOLBAR_usersextras {
	/**
	* Draws the menu for a New users
	*/
	function _NEW() {
		mosMenuBar::startTable();
		mosMenuBar::save();
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	
	function _EDIT() {
		mosMenuBar::startTable();
		mosMenuBar::save();
		mosMenuBar::cancel('showusers');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}

	function _NEW_TAB() {
		mosMenuBar::startTable();
		mosMenuBar::save('saveTab');
		mosMenuBar::cancel('showTab');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	
	function _EDIT_TAB() {
		mosMenuBar::startTable();
		mosMenuBar::save('saveTab');
		mosMenuBar::cancel('showTab');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	function _DEFAULT_TAB() {
		mosMenuBar::startTable();
		mosMenuBar::custom( 'newTab', 'new.png', 'new_f2.png', 'New Tab', false );
		mosMenuBar::editList('editTab');
		mosMenuBar::deleteList('The tab will be deleted and cannot be undone!','removeTab');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	function _NEW_FIELD() {
		mosMenuBar::startTable();
		mosMenuBar::save('saveField');
		mosMenuBar::cancel('showField');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	
	function _EDIT_FIELD() {
		mosMenuBar::startTable();
		mosMenuBar::save('saveField');
		mosMenuBar::cancel('showField');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	function _DEFAULT_FIELD() {
		mosMenuBar::startTable();
		mosMenuBar::custom( 'newField', 'new.png', 'new_f2.png', 'New Field', false );
		mosMenuBar::editList('editField');
		mosMenuBar::deleteList('The Field and all user data associated to this field will be lost and cannot be undone!','removeField');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	function _NEW_LIST() {
		mosMenuBar::startTable();
		mosMenuBar::save('saveList');
		mosMenuBar::cancel('showLists');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	
	function _EDIT_LIST() {
		mosMenuBar::startTable();
		mosMenuBar::save('saveList');
		mosMenuBar::cancel('showLists');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	function _DEFAULT_LIST() {
		mosMenuBar::startTable();
		mosMenuBar::custom( 'newList', 'new.png', 'new_f2.png', 'New List', false );
		mosMenuBar::editList('editList');
		mosMenuBar::deleteList('The selected List(s) will be deleted and cannot be undone!','removeList');
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	function _EDIT_CONFIG() {
		mosMenuBar::startTable();
		mosMenuBar::save('saveconfig');
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}

	
	function _DEFAULT() {
		mosMenuBar::startTable();
		mosMenuBar::addNew();
		mosMenuBar::editList();
		mosMenuBar::deleteList();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
}
?>